# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'To_PerlSCX'}{'format'} = 'sw'; # string, but some elements are interpreted as a list; white space occurs only as list item separators
$Unicode::UCD::SwashInfo{'To_PerlSCX'}{'missing'} = 'Unknown';

return <<'END';
0	40	Common
41	5A	Latin
5B	60	Common
61	7A	Latin
7B	A9	Common
AA		Latin
AB	B9	Common
BA		Latin
BB	BF	Common
C0	D6	Latin
D7		Common
D8	F6	Latin
F7		Common
F8	2B8	Latin
2B9	2DF	Common
2E0	2E4	Latin
2E5	2E9	Common
2EA	2EB	Bopomofo Hanb
2EC	2FF	Common
300	341	Inherited
342		Greek
343	344	Inherited
345		Greek
346	362	Inherited
363	36F	Latin
370	373	Greek
374		Common
375	377	Greek
37A	37D	Greek
37E		Common
37F		Greek
384		Greek
385		Common
386		Greek
387		Common
388	38A	Greek
38C		Greek
38E	3A1	Greek
3A3	3E1	Greek
3E2	3EF	Coptic
3F0	3FF	Greek
400	482	Cyrillic
483		Cyrillic Old_Permic
484		Cyrillic Glagolitic
485	486	Cyrillic Latin
487		Cyrillic Glagolitic
488	52F	Cyrillic
531	556	Armenian
559	58A	Armenian
58D	58F	Armenian
591	5C7	Hebrew
5D0	5EA	Hebrew
5EF	5F4	Hebrew
600	604	Arabic
605		Common
606	60B	Arabic
60C		Arabic Nko Hanifi_Rohingya Syriac Thaana Yezidi
60D	61A	Arabic
61B		Arabic Nko Hanifi_Rohingya Syriac Thaana Yezidi
61C		Arabic Syriac Thaana
61D	61E	Arabic
61F		Adlam Arabic Nko Hanifi_Rohingya Syriac Thaana Yezidi
620	63F	Arabic
640		Adlam Arabic Mandaic Manichaean Old_Uyghur Psalter_Pahlavi Hanifi_Rohingya Sogdian Syriac
641	64A	Arabic
64B	655	Arabic Syriac
656	65F	Arabic
660	669	Arabic Thaana Yezidi
66A	66F	Arabic
670		Arabic Syriac
671	6D3	Arabic
6D4		Arabic Hanifi_Rohingya
6D5	6DC	Arabic
6DD		Common
6DE	6FF	Arabic
700	70D	Syriac
70F	74A	Syriac
74D	74F	Syriac
750	77F	Arabic
780	7B1	Thaana
7C0	7FA	Nko
7FD	7FF	Nko
800	82D	Samaritan
830	83E	Samaritan
840	85B	Mandaic
85E		Mandaic
860	86A	Syriac
870	88E	Arabic
890	891	Arabic
898	8E1	Arabic
8E2		Common
8E3	8FF	Arabic
900	950	Devanagari
951		Bengali Devanagari Grantha Gujarati Gurmukhi Kannada Latin Malayalam Oriya Sharada Tamil Telugu Tirhuta
952		Bengali Devanagari Grantha Gujarati Gurmukhi Kannada Latin Malayalam Oriya Tamil Telugu Tirhuta
953	954	Inherited
955	963	Devanagari
964		Bengali Devanagari Dogra Gunjala_Gondi Masaram_Gondi Grantha Gujarati Gurmukhi Kannada Mahajani Malayalam Nandinagari Oriya Khudawadi Sinhala Syloti_Nagri Takri Tamil Telugu Tirhuta
965		Bengali Devanagari Dogra Gunjala_Gondi Masaram_Gondi Grantha Gujarati Gurmukhi Kannada Limbu Mahajani Malayalam Nandinagari Oriya Khudawadi Sinhala Syloti_Nagri Takri Tamil Telugu Tirhuta
966	96F	Devanagari Dogra Kaithi Mahajani
970	97F	Devanagari
980	983	Bengali
985	98C	Bengali
98F	990	Bengali
993	9A8	Bengali
9AA	9B0	Bengali
9B2		Bengali
9B6	9B9	Bengali
9BC	9C4	Bengali
9C7	9C8	Bengali
9CB	9CE	Bengali
9D7		Bengali
9DC	9DD	Bengali
9DF	9E3	Bengali
9E6	9EF	Bengali Chakma Syloti_Nagri
9F0	9FE	Bengali
A01	A03	Gurmukhi
A05	A0A	Gurmukhi
A0F	A10	Gurmukhi
A13	A28	Gurmukhi
A2A	A30	Gurmukhi
A32	A33	Gurmukhi
A35	A36	Gurmukhi
A38	A39	Gurmukhi
A3C		Gurmukhi
A3E	A42	Gurmukhi
A47	A48	Gurmukhi
A4B	A4D	Gurmukhi
A51		Gurmukhi
A59	A5C	Gurmukhi
A5E		Gurmukhi
A66	A6F	Gurmukhi Multani
A70	A76	Gurmukhi
A81	A83	Gujarati
A85	A8D	Gujarati
A8F	A91	Gujarati
A93	AA8	Gujarati
AAA	AB0	Gujarati
AB2	AB3	Gujarati
AB5	AB9	Gujarati
ABC	AC5	Gujarati
AC7	AC9	Gujarati
ACB	ACD	Gujarati
AD0		Gujarati
AE0	AE3	Gujarati
AE6	AEF	Gujarati Khojki
AF0	AF1	Gujarati
AF9	AFF	Gujarati
B01	B03	Oriya
B05	B0C	Oriya
B0F	B10	Oriya
B13	B28	Oriya
B2A	B30	Oriya
B32	B33	Oriya
B35	B39	Oriya
B3C	B44	Oriya
B47	B48	Oriya
B4B	B4D	Oriya
B55	B57	Oriya
B5C	B5D	Oriya
B5F	B63	Oriya
B66	B77	Oriya
B82	B83	Tamil
B85	B8A	Tamil
B8E	B90	Tamil
B92	B95	Tamil
B99	B9A	Tamil
B9C		Tamil
B9E	B9F	Tamil
BA3	BA4	Tamil
BA8	BAA	Tamil
BAE	BB9	Tamil
BBE	BC2	Tamil
BC6	BC8	Tamil
BCA	BCD	Tamil
BD0		Tamil
BD7		Tamil
BE6	BF3	Grantha Tamil
BF4	BFA	Tamil
C00	C0C	Telugu
C0E	C10	Telugu
C12	C28	Telugu
C2A	C39	Telugu
C3C	C44	Telugu
C46	C48	Telugu
C4A	C4D	Telugu
C55	C56	Telugu
C58	C5A	Telugu
C5D		Telugu
C60	C63	Telugu
C66	C6F	Telugu
C77	C7F	Telugu
C80	C8C	Kannada
C8E	C90	Kannada
C92	CA8	Kannada
CAA	CB3	Kannada
CB5	CB9	Kannada
CBC	CC4	Kannada
CC6	CC8	Kannada
CCA	CCD	Kannada
CD5	CD6	Kannada
CDD	CDE	Kannada
CE0	CE3	Kannada
CE6	CEF	Kannada Nandinagari
CF1	CF2	Kannada
D00	D0C	Malayalam
D0E	D10	Malayalam
D12	D44	Malayalam
D46	D48	Malayalam
D4A	D4F	Malayalam
D54	D63	Malayalam
D66	D7F	Malayalam
D81	D83	Sinhala
D85	D96	Sinhala
D9A	DB1	Sinhala
DB3	DBB	Sinhala
DBD		Sinhala
DC0	DC6	Sinhala
DCA		Sinhala
DCF	DD4	Sinhala
DD6		Sinhala
DD8	DDF	Sinhala
DE6	DEF	Sinhala
DF2	DF4	Sinhala
E01	E3A	Thai
E3F		Common
E40	E5B	Thai
E81	E82	Lao
E84		Lao
E86	E8A	Lao
E8C	EA3	Lao
EA5		Lao
EA7	EBD	Lao
EC0	EC4	Lao
EC6		Lao
EC8	ECD	Lao
ED0	ED9	Lao
EDC	EDF	Lao
F00	F47	Tibetan
F49	F6C	Tibetan
F71	F97	Tibetan
F99	FBC	Tibetan
FBE	FCC	Tibetan
FCE	FD4	Tibetan
FD5	FD8	Common
FD9	FDA	Tibetan
1000	103F	Myanmar
1040	1049	Chakma Myanmar Tai_Le
104A	109F	Myanmar
10A0	10C5	Georgian
10C7		Georgian
10CD		Georgian
10D0	10FA	Georgian
10FB		Georgian Latin
10FC	10FF	Georgian
1100	11FF	Hangul Kore
1200	1248	Ethiopic
124A	124D	Ethiopic
1250	1256	Ethiopic
1258		Ethiopic
125A	125D	Ethiopic
1260	1288	Ethiopic
128A	128D	Ethiopic
1290	12B0	Ethiopic
12B2	12B5	Ethiopic
12B8	12BE	Ethiopic
12C0		Ethiopic
12C2	12C5	Ethiopic
12C8	12D6	Ethiopic
12D8	1310	Ethiopic
1312	1315	Ethiopic
1318	135A	Ethiopic
135D	137C	Ethiopic
1380	1399	Ethiopic
13A0	13F5	Cherokee
13F8	13FD	Cherokee
1400	167F	Canadian_Aboriginal
1680	169C	Ogham
16A0	16EA	Runic
16EB	16ED	Common
16EE	16F8	Runic
1700	1715	Tagalog
171F		Tagalog
1720	1734	Hanunoo
1735	1736	Buhid Hanunoo Tagbanwa Tagalog
1740	1753	Buhid
1760	176C	Tagbanwa
176E	1770	Tagbanwa
1772	1773	Tagbanwa
1780	17DD	Khmer
17E0	17E9	Khmer
17F0	17F9	Khmer
1800	1801	Mongolian
1802	1803	Mongolian Phags_Pa
1804		Mongolian
1805		Mongolian Phags_Pa
1806	1819	Mongolian
1820	1878	Mongolian
1880	18AA	Mongolian
18B0	18F5	Canadian_Aboriginal
1900	191E	Limbu
1920	192B	Limbu
1930	193B	Limbu
1940		Limbu
1944	194F	Limbu
1950	196D	Tai_Le
1970	1974	Tai_Le
1980	19AB	New_Tai_Lue
19B0	19C9	New_Tai_Lue
19D0	19DA	New_Tai_Lue
19DE	19DF	New_Tai_Lue
19E0	19FF	Khmer
1A00	1A1B	Buginese
1A1E	1A1F	Buginese
1A20	1A5E	Tai_Tham
1A60	1A7C	Tai_Tham
1A7F	1A89	Tai_Tham
1A90	1A99	Tai_Tham
1AA0	1AAD	Tai_Tham
1AB0	1ACE	Inherited
1B00	1B4C	Balinese
1B50	1B7E	Balinese
1B80	1BBF	Sundanese
1BC0	1BF3	Batak
1BFC	1BFF	Batak
1C00	1C37	Lepcha
1C3B	1C49	Lepcha
1C4D	1C4F	Lepcha
1C50	1C7F	Ol_Chiki
1C80	1C88	Cyrillic
1C90	1CBA	Georgian
1CBD	1CBF	Georgian
1CC0	1CC7	Sundanese
1CD0		Bengali Devanagari Grantha Kannada
1CD1		Devanagari
1CD2		Bengali Devanagari Grantha Kannada
1CD3		Devanagari Grantha
1CD4		Devanagari
1CD5	1CD6	Bengali Devanagari
1CD7		Devanagari Sharada
1CD8		Bengali Devanagari
1CD9		Devanagari Sharada
1CDA		Devanagari Kannada Malayalam Oriya Tamil Telugu
1CDB		Devanagari
1CDC	1CDD	Devanagari Sharada
1CDE	1CDF	Devanagari
1CE0		Devanagari Sharada
1CE1		Bengali Devanagari
1CE2	1CE8	Devanagari
1CE9		Devanagari Nandinagari
1CEA		Bengali Devanagari
1CEB	1CEC	Devanagari
1CED		Bengali Devanagari
1CEE	1CF1	Devanagari
1CF2		Bengali Devanagari Grantha Kannada Nandinagari Oriya Telugu Tirhuta
1CF3		Devanagari Grantha
1CF4		Devanagari Grantha Kannada
1CF5	1CF6	Bengali Devanagari
1CF7		Bengali
1CF8	1CF9	Devanagari Grantha
1CFA		Nandinagari
1D00	1D25	Latin
1D26	1D2A	Greek
1D2B		Cyrillic
1D2C	1D5C	Latin
1D5D	1D61	Greek
1D62	1D65	Latin
1D66	1D6A	Greek
1D6B	1D77	Latin
1D78		Cyrillic
1D79	1DBE	Latin
1DBF	1DC1	Greek
1DC2	1DF7	Inherited
1DF8		Cyrillic Syriac
1DF9		Inherited
1DFA		Syriac
1DFB	1DFF	Inherited
1E00	1EFF	Latin
1F00	1F15	Greek
1F18	1F1D	Greek
1F20	1F45	Greek
1F48	1F4D	Greek
1F50	1F57	Greek
1F59		Greek
1F5B		Greek
1F5D		Greek
1F5F	1F7D	Greek
1F80	1FB4	Greek
1FB6	1FC4	Greek
1FC6	1FD3	Greek
1FD6	1FDB	Greek
1FDD	1FEF	Greek
1FF2	1FF4	Greek
1FF6	1FFE	Greek
2000	200B	Common
200C	200D	Inherited
200E	202E	Common
202F		Latin Mongolian
2030	2064	Common
2066	2070	Common
2071		Latin
2074	207E	Common
207F		Latin
2080	208E	Common
2090	209C	Latin
20A0	20C0	Common
20D0	20EF	Inherited
20F0		Devanagari Grantha Latin
2100	2125	Common
2126		Greek
2127	2129	Common
212A	212B	Latin
212C	2131	Common
2132		Latin
2133	214D	Common
214E		Latin
214F	215F	Common
2160	2188	Latin
2189	218B	Common
2190	2426	Common
2440	244A	Common
2460	27FF	Common
2800	28FF	Braille
2900	2B73	Common
2B76	2B95	Common
2B97	2BFF	Common
2C00	2C5F	Glagolitic
2C60	2C7F	Latin
2C80	2CF3	Coptic
2CF9	2CFF	Coptic
2D00	2D25	Georgian
2D27		Georgian
2D2D		Georgian
2D30	2D67	Tifinagh
2D6F	2D70	Tifinagh
2D7F		Tifinagh
2D80	2D96	Ethiopic
2DA0	2DA6	Ethiopic
2DA8	2DAE	Ethiopic
2DB0	2DB6	Ethiopic
2DB8	2DBE	Ethiopic
2DC0	2DC6	Ethiopic
2DC8	2DCE	Ethiopic
2DD0	2DD6	Ethiopic
2DD8	2DDE	Ethiopic
2DE0	2DFF	Cyrillic
2E00	2E42	Common
2E43		Cyrillic Glagolitic
2E44	2E5D	Common
2E80	2E99	Han Hanb Jpan Kore
2E9B	2EF3	Han Hanb Jpan Kore
2F00	2FD5	Han Hanb Jpan Kore
2FF0	2FFB	Common
3000		Common
3001	3002	Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana Yi
3003		Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana
3004		Common
3005	3007	Han Hanb Jpan Kore
3008	3011	Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana Yi
3012		Common
3013		Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana
3014	301B	Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana Yi
301C	301F	Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana
3020		Common
3021	3029	Han Hanb Jpan Kore
302A	302D	Bopomofo Hanb Han Jpan Kore
302E	302F	Hangul Kore
3030		Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana
3031	3035	Hiragana Jpan Katakana
3036		Common
3037		Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana
3038	303B	Han Hanb Jpan Kore
303C	303D	Han Hanb Jpan Kore Hiragana Katakana
303E	303F	Han Hanb Jpan Kore
3041	3096	Hiragana Jpan
3099	309C	Hiragana Jpan Katakana
309D	309F	Hiragana Jpan
30A0		Hiragana Jpan Katakana
30A1	30FA	Katakana Jpan
30FB		Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana Yi
30FC		Hiragana Jpan Katakana
30FD	30FF	Katakana Jpan
3105	312F	Bopomofo Hanb
3131	318E	Hangul Kore
3190	319F	Han Hanb Jpan Kore
31A0	31BF	Bopomofo Hanb
31C0	31E3	Han Hanb Jpan Kore
31F0	31FF	Katakana Jpan
3200	321E	Hangul Kore
3220	3247	Han Hanb Jpan Kore
3248	325F	Common
3260	327E	Hangul Kore
327F		Common
3280	32B0	Han Hanb Jpan Kore
32B1	32BF	Common
32C0	32CB	Han Hanb Jpan Kore
32CC	32CF	Common
32D0	32FE	Katakana Jpan
32FF		Han Hanb Jpan Kore
3300	3357	Katakana Jpan
3358	3370	Han Hanb Jpan Kore
3371	337A	Common
337B	337F	Han Hanb Jpan Kore
3380	33DF	Common
33E0	33FE	Han Hanb Jpan Kore
33FF		Common
3400	4DBF	Han Hanb Jpan Kore
4DC0	4DFF	Common
4E00	9FFF	Han Hanb Jpan Kore
A000	A48C	Yi
A490	A4C6	Yi
A4D0	A4FF	Lisu
A500	A62B	Vai
A640	A66E	Cyrillic
A66F		Cyrillic Glagolitic
A670	A69F	Cyrillic
A6A0	A6F7	Bamum
A700	A707	Han Hanb Jpan Kore Latin
A708	A721	Common
A722	A787	Latin
A788	A78A	Common
A78B	A7CA	Latin
A7D0	A7D1	Latin
A7D3		Latin
A7D5	A7D9	Latin
A7F2	A7FF	Latin
A800	A82C	Syloti_Nagri
A830	A832	Devanagari Dogra Gujarati Gurmukhi Khojki Kannada Kaithi Mahajani Malayalam Modi Nandinagari Khudawadi Takri Tirhuta
A833	A835	Devanagari Dogra Gujarati Gurmukhi Khojki Kannada Kaithi Mahajani Modi Nandinagari Khudawadi Takri Tirhuta
A836	A839	Devanagari Dogra Gujarati Gurmukhi Khojki Kaithi Mahajani Modi Khudawadi Takri Tirhuta
A840	A877	Phags_Pa
A880	A8C5	Saurashtra
A8CE	A8D9	Saurashtra
A8E0	A8F0	Devanagari
A8F1		Bengali Devanagari
A8F2		Devanagari
A8F3		Devanagari Tamil
A8F4	A8FF	Devanagari
A900	A92D	Kayah_Li
A92E		Kayah_Li Latin Myanmar
A92F		Kayah_Li
A930	A953	Rejang
A95F		Rejang
A960	A97C	Hangul Kore
A980	A9CD	Javanese
A9CF		Buginese Javanese
A9D0	A9D9	Javanese
A9DE	A9DF	Javanese
A9E0	A9FE	Myanmar
AA00	AA36	Cham
AA40	AA4D	Cham
AA50	AA59	Cham
AA5C	AA5F	Cham
AA60	AA7F	Myanmar
AA80	AAC2	Tai_Viet
AADB	AADF	Tai_Viet
AAE0	AAF6	Meetei_Mayek
AB01	AB06	Ethiopic
AB09	AB0E	Ethiopic
AB11	AB16	Ethiopic
AB20	AB26	Ethiopic
AB28	AB2E	Ethiopic
AB30	AB5A	Latin
AB5B		Common
AB5C	AB64	Latin
AB65		Greek
AB66	AB69	Latin
AB6A	AB6B	Common
AB70	ABBF	Cherokee
ABC0	ABED	Meetei_Mayek
ABF0	ABF9	Meetei_Mayek
AC00	D7A3	Hangul Kore
D7B0	D7C6	Hangul Kore
D7CB	D7FB	Hangul Kore
F900	FA6D	Han Hanb Jpan Kore
FA70	FAD9	Han Hanb Jpan Kore
FB00	FB06	Latin
FB13	FB17	Armenian
FB1D	FB36	Hebrew
FB38	FB3C	Hebrew
FB3E		Hebrew
FB40	FB41	Hebrew
FB43	FB44	Hebrew
FB46	FB4F	Hebrew
FB50	FBC2	Arabic
FBD3	FD3D	Arabic
FD3E	FD3F	Arabic Nko
FD40	FD8F	Arabic
FD92	FDC7	Arabic
FDCF		Arabic
FDF0	FDF1	Arabic
FDF2		Arabic Thaana
FDF3	FDFC	Arabic
FDFD		Arabic Thaana
FDFE	FDFF	Arabic
FE00	FE0F	Inherited
FE10	FE19	Common
FE20	FE2D	Inherited
FE2E	FE2F	Cyrillic
FE30	FE44	Common
FE45	FE46	Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana
FE47	FE52	Common
FE54	FE66	Common
FE68	FE6B	Common
FE70	FE74	Arabic
FE76	FEFC	Arabic
FEFF		Common
FF01	FF20	Common
FF21	FF3A	Latin
FF3B	FF40	Common
FF41	FF5A	Latin
FF5B	FF60	Common
FF61	FF65	Bopomofo Hanb Hangul Kore Han Jpan Hiragana Katakana Yi
FF66	FF6F	Katakana Jpan
FF70		Hiragana Jpan Katakana
FF71	FF9D	Katakana Jpan
FF9E	FF9F	Hiragana Jpan Katakana
FFA0	FFBE	Hangul Kore
FFC2	FFC7	Hangul Kore
FFCA	FFCF	Hangul Kore
FFD2	FFD7	Hangul Kore
FFDA	FFDC	Hangul Kore
FFE0	FFE6	Common
FFE8	FFEE	Common
FFF9	FFFD	Common
10000	1000B	Linear_B
1000D	10026	Linear_B
10028	1003A	Linear_B
1003C	1003D	Linear_B
1003F	1004D	Linear_B
10050	1005D	Linear_B
10080	100FA	Linear_B
10100	10101	Cypro_Minoan Cypriot Linear_B
10102		Cypriot Linear_B
10107	10133	Cypriot Linear_A Linear_B
10137	1013F	Cypriot Linear_B
10140	1018E	Greek
10190	1019C	Common
101A0		Greek
101D0	101FC	Common
101FD		Inherited
10280	1029C	Lycian
102A0	102D0	Carian
102E0	102FB	Arabic Coptic
10300	10323	Old_Italic
1032D	1032F	Old_Italic
10330	1034A	Gothic
10350	1037A	Old_Permic
10380	1039D	Ugaritic
1039F		Ugaritic
103A0	103C3	Old_Persian
103C8	103D5	Old_Persian
10400	1044F	Deseret
10450	1047F	Shavian
10480	1049D	Osmanya
104A0	104A9	Osmanya
104B0	104D3	Osage
104D8	104FB	Osage
10500	10527	Elbasan
10530	10563	Caucasian_Albanian
1056F		Caucasian_Albanian
10570	1057A	Vithkuqi
1057C	1058A	Vithkuqi
1058C	10592	Vithkuqi
10594	10595	Vithkuqi
10597	105A1	Vithkuqi
105A3	105B1	Vithkuqi
105B3	105B9	Vithkuqi
105BB	105BC	Vithkuqi
10600	10736	Linear_A
10740	10755	Linear_A
10760	10767	Linear_A
10780	10785	Latin
10787	107B0	Latin
107B2	107BA	Latin
10800	10805	Cypriot
10808		Cypriot
1080A	10835	Cypriot
10837	10838	Cypriot
1083C		Cypriot
1083F		Cypriot
10840	10855	Imperial_Aramaic
10857	1085F	Imperial_Aramaic
10860	1087F	Palmyrene
10880	1089E	Nabataean
108A7	108AF	Nabataean
108E0	108F2	Hatran
108F4	108F5	Hatran
108FB	108FF	Hatran
10900	1091B	Phoenician
1091F		Phoenician
10920	10939	Lydian
1093F		Lydian
10980	1099F	Meroitic_Hieroglyphs
109A0	109B7	Meroitic_Cursive
109BC	109CF	Meroitic_Cursive
109D2	109FF	Meroitic_Cursive
10A00	10A03	Kharoshthi
10A05	10A06	Kharoshthi
10A0C	10A13	Kharoshthi
10A15	10A17	Kharoshthi
10A19	10A35	Kharoshthi
10A38	10A3A	Kharoshthi
10A3F	10A48	Kharoshthi
10A50	10A58	Kharoshthi
10A60	10A7F	Old_South_Arabian
10A80	10A9F	Old_North_Arabian
10AC0	10AE6	Manichaean
10AEB	10AF1	Manichaean
10AF2		Manichaean Old_Uyghur
10AF3	10AF6	Manichaean
10B00	10B35	Avestan
10B39	10B3F	Avestan
10B40	10B55	Inscriptional_Parthian
10B58	10B5F	Inscriptional_Parthian
10B60	10B72	Inscriptional_Pahlavi
10B78	10B7F	Inscriptional_Pahlavi
10B80	10B91	Psalter_Pahlavi
10B99	10B9C	Psalter_Pahlavi
10BA9	10BAF	Psalter_Pahlavi
10C00	10C48	Old_Turkic
10C80	10CB2	Old_Hungarian
10CC0	10CF2	Old_Hungarian
10CFA	10CFF	Old_Hungarian
10D00	10D27	Hanifi_Rohingya
10D30	10D39	Hanifi_Rohingya
10E60	10E7E	Arabic
10E80	10EA9	Yezidi
10EAB	10EAD	Yezidi
10EB0	10EB1	Yezidi
10F00	10F27	Old_Sogdian
10F30	10F59	Sogdian
10F70	10F89	Old_Uyghur
10FB0	10FCB	Chorasmian
10FE0	10FF6	Elymaic
11000	1104D	Brahmi
11052	11075	Brahmi
1107F		Brahmi
11080	110C2	Kaithi
110CD		Kaithi
110D0	110E8	Sora_Sompeng
110F0	110F9	Sora_Sompeng
11100	11134	Chakma
11136	11147	Chakma
11150	11176	Mahajani
11180	111DF	Sharada
111E1	111F4	Sinhala
11200	11211	Khojki
11213	1123E	Khojki
11280	11286	Multani
11288		Multani
1128A	1128D	Multani
1128F	1129D	Multani
1129F	112A9	Multani
112B0	112EA	Khudawadi
112F0	112F9	Khudawadi
11300		Grantha
11301		Grantha Tamil
11302		Grantha
11303		Grantha Tamil
11305	1130C	Grantha
1130F	11310	Grantha
11313	11328	Grantha
1132A	11330	Grantha
11332	11333	Grantha
11335	11339	Grantha
1133B	1133C	Grantha Tamil
1133D	11344	Grantha
11347	11348	Grantha
1134B	1134D	Grantha
11350		Grantha
11357		Grantha
1135D	11363	Grantha
11366	1136C	Grantha
11370	11374	Grantha
11400	1145B	Newa
1145D	11461	Newa
11480	114C7	Tirhuta
114D0	114D9	Tirhuta
11580	115B5	Siddham
115B8	115DD	Siddham
11600	11644	Modi
11650	11659	Modi
11660	1166C	Mongolian
11680	116B9	Takri
116C0	116C9	Takri
11700	1171A	Ahom
1171D	1172B	Ahom
11730	11746	Ahom
11800	1183B	Dogra
118A0	118F2	Warang_Citi
118FF		Warang_Citi
11900	11906	Dives_Akuru
11909		Dives_Akuru
1190C	11913	Dives_Akuru
11915	11916	Dives_Akuru
11918	11935	Dives_Akuru
11937	11938	Dives_Akuru
1193B	11946	Dives_Akuru
11950	11959	Dives_Akuru
119A0	119A7	Nandinagari
119AA	119D7	Nandinagari
119DA	119E4	Nandinagari
11A00	11A47	Zanabazar_Square
11A50	11AA2	Soyombo
11AB0	11ABF	Canadian_Aboriginal
11AC0	11AF8	Pau_Cin_Hau
11C00	11C08	Bhaiksuki
11C0A	11C36	Bhaiksuki
11C38	11C45	Bhaiksuki
11C50	11C6C	Bhaiksuki
11C70	11C8F	Marchen
11C92	11CA7	Marchen
11CA9	11CB6	Marchen
11D00	11D06	Masaram_Gondi
11D08	11D09	Masaram_Gondi
11D0B	11D36	Masaram_Gondi
11D3A		Masaram_Gondi
11D3C	11D3D	Masaram_Gondi
11D3F	11D47	Masaram_Gondi
11D50	11D59	Masaram_Gondi
11D60	11D65	Gunjala_Gondi
11D67	11D68	Gunjala_Gondi
11D6A	11D8E	Gunjala_Gondi
11D90	11D91	Gunjala_Gondi
11D93	11D98	Gunjala_Gondi
11DA0	11DA9	Gunjala_Gondi
11EE0	11EF8	Makasar
11FB0		Lisu
11FC0	11FCF	Tamil
11FD0	11FD1	Grantha Tamil
11FD2		Tamil
11FD3		Grantha Tamil
11FD4	11FF1	Tamil
11FFF		Tamil
12000	12399	Cuneiform
12400	1246E	Cuneiform
12470	12474	Cuneiform
12480	12543	Cuneiform
12F90	12FF2	Cypro_Minoan
13000	1342E	Egyptian_Hieroglyphs
13430	13438	Egyptian_Hieroglyphs
14400	14646	Anatolian_Hieroglyphs
16800	16A38	Bamum
16A40	16A5E	Mro
16A60	16A69	Mro
16A6E	16A6F	Mro
16A70	16ABE	Tangsa
16AC0	16AC9	Tangsa
16AD0	16AED	Bassa_Vah
16AF0	16AF5	Bassa_Vah
16B00	16B45	Pahawh_Hmong
16B50	16B59	Pahawh_Hmong
16B5B	16B61	Pahawh_Hmong
16B63	16B77	Pahawh_Hmong
16B7D	16B8F	Pahawh_Hmong
16E40	16E9A	Medefaidrin
16F00	16F4A	Miao
16F4F	16F87	Miao
16F8F	16F9F	Miao
16FE0		Tangut
16FE1		Nushu
16FE2	16FE3	Han Hanb Jpan Kore
16FE4		Khitan_Small_Script
16FF0	16FF1	Han Hanb Jpan Kore
17000	187F7	Tangut
18800	18AFF	Tangut
18B00	18CD5	Khitan_Small_Script
18D00	18D08	Tangut
1AFF0	1AFF3	Katakana Jpan
1AFF5	1AFFB	Katakana Jpan
1AFFD	1AFFE	Katakana Jpan
1B000		Katakana Jpan
1B001	1B11F	Hiragana Jpan
1B120	1B122	Katakana Jpan
1B150	1B152	Hiragana Jpan
1B164	1B167	Katakana Jpan
1B170	1B2FB	Nushu
1BC00	1BC6A	Duployan
1BC70	1BC7C	Duployan
1BC80	1BC88	Duployan
1BC90	1BC99	Duployan
1BC9C	1BCA3	Duployan
1CF00	1CF2D	Inherited
1CF30	1CF46	Inherited
1CF50	1CFC3	Common
1D000	1D0F5	Common
1D100	1D126	Common
1D129	1D166	Common
1D167	1D169	Inherited
1D16A	1D17A	Common
1D17B	1D182	Inherited
1D183	1D184	Common
1D185	1D18B	Inherited
1D18C	1D1A9	Common
1D1AA	1D1AD	Inherited
1D1AE	1D1EA	Common
1D200	1D245	Greek
1D2E0	1D2F3	Common
1D300	1D356	Common
1D360	1D371	Han Hanb Jpan Kore
1D372	1D378	Common
1D400	1D454	Common
1D456	1D49C	Common
1D49E	1D49F	Common
1D4A2		Common
1D4A5	1D4A6	Common
1D4A9	1D4AC	Common
1D4AE	1D4B9	Common
1D4BB		Common
1D4BD	1D4C3	Common
1D4C5	1D505	Common
1D507	1D50A	Common
1D50D	1D514	Common
1D516	1D51C	Common
1D51E	1D539	Common
1D53B	1D53E	Common
1D540	1D544	Common
1D546		Common
1D54A	1D550	Common
1D552	1D6A5	Common
1D6A8	1D7CB	Common
1D7CE	1D7FF	Common
1D800	1DA8B	SignWriting
1DA9B	1DA9F	SignWriting
1DAA1	1DAAF	SignWriting
1DF00	1DF1E	Latin
1E000	1E006	Glagolitic
1E008	1E018	Glagolitic
1E01B	1E021	Glagolitic
1E023	1E024	Glagolitic
1E026	1E02A	Glagolitic
1E100	1E12C	Nyiakeng_Puachue_Hmong
1E130	1E13D	Nyiakeng_Puachue_Hmong
1E140	1E149	Nyiakeng_Puachue_Hmong
1E14E	1E14F	Nyiakeng_Puachue_Hmong
1E290	1E2AE	Toto
1E2C0	1E2F9	Wancho
1E2FF		Wancho
1E7E0	1E7E6	Ethiopic
1E7E8	1E7EB	Ethiopic
1E7ED	1E7EE	Ethiopic
1E7F0	1E7FE	Ethiopic
1E800	1E8C4	Mende_Kikakui
1E8C7	1E8D6	Mende_Kikakui
1E900	1E94B	Adlam
1E950	1E959	Adlam
1E95E	1E95F	Adlam
1EC71	1ECB4	Common
1ED01	1ED3D	Common
1EE00	1EE03	Arabic
1EE05	1EE1F	Arabic
1EE21	1EE22	Arabic
1EE24		Arabic
1EE27		Arabic
1EE29	1EE32	Arabic
1EE34	1EE37	Arabic
1EE39		Arabic
1EE3B		Arabic
1EE42		Arabic
1EE47		Arabic
1EE49		Arabic
1EE4B		Arabic
1EE4D	1EE4F	Arabic
1EE51	1EE52	Arabic
1EE54		Arabic
1EE57		Arabic
1EE59		Arabic
1EE5B		Arabic
1EE5D		Arabic
1EE5F		Arabic
1EE61	1EE62	Arabic
1EE64		Arabic
1EE67	1EE6A	Arabic
1EE6C	1EE72	Arabic
1EE74	1EE77	Arabic
1EE79	1EE7C	Arabic
1EE7E		Arabic
1EE80	1EE89	Arabic
1EE8B	1EE9B	Arabic
1EEA1	1EEA3	Arabic
1EEA5	1EEA9	Arabic
1EEAB	1EEBB	Arabic
1EEF0	1EEF1	Arabic
1F000	1F02B	Common
1F030	1F093	Common
1F0A0	1F0AE	Common
1F0B1	1F0BF	Common
1F0C1	1F0CF	Common
1F0D1	1F0F5	Common
1F100	1F1AD	Common
1F1E6	1F1FF	Common
1F200		Hiragana Jpan
1F201	1F202	Common
1F210	1F23B	Common
1F240	1F248	Common
1F250	1F251	Han Hanb Jpan Kore
1F260	1F265	Common
1F300	1F6D7	Common
1F6DD	1F6EC	Common
1F6F0	1F6FC	Common
1F700	1F773	Common
1F780	1F7D8	Common
1F7E0	1F7EB	Common
1F7F0		Common
1F800	1F80B	Common
1F810	1F847	Common
1F850	1F859	Common
1F860	1F887	Common
1F890	1F8AD	Common
1F8B0	1F8B1	Common
1F900	1FA53	Common
1FA60	1FA6D	Common
1FA70	1FA74	Common
1FA78	1FA7C	Common
1FA80	1FA86	Common
1FA90	1FAAC	Common
1FAB0	1FABA	Common
1FAC0	1FAC5	Common
1FAD0	1FAD9	Common
1FAE0	1FAE7	Common
1FAF0	1FAF6	Common
1FB00	1FB92	Common
1FB94	1FBCA	Common
1FBF0	1FBF9	Common
20000	2A6DF	Han Hanb Jpan Kore
2A700	2B738	Han Hanb Jpan Kore
2B740	2B81D	Han Hanb Jpan Kore
2B820	2CEA1	Han Hanb Jpan Kore
2CEB0	2EBE0	Han Hanb Jpan Kore
2F800	2FA1D	Han Hanb Jpan Kore
30000	3134A	Han Hanb Jpan Kore
E0001		Common
E0020	E007F	Common
E0100	E01EF	Inherited
END
