# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V48
35
38
162
166
176
178
1423
1424
1545
1547
1642
1643
2546
2548
2555
2556
2801
2802
3065
3066
3647
3648
6107
6108
8240
8245
8352
8400
8494
8495
8723
8724
43064
43066
65119
65120
65129
65131
65283
65286
65504
65506
65509
65511
73693
73697
123647
123648
END
