# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V54
2381
2382
2509
2510
2637
2638
2765
2766
2893
2894
3021
3022
3149
3150
3277
3278
3405
3406
3530
3531
6980
6981
43014
43015
43204
43205
43456
43457
69702
69703
69817
69818
70080
70081
70197
70198
70477
70478
70722
70723
70850
70851
71103
71104
71231
71232
71350
71351
71737
71738
72160
72161
72767
72768
END
