# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V50
36
37
43
44
92
93
163
166
177
178
1423
1424
2046
2048
2555
2556
2801
2802
3065
3066
3647
3648
6107
6108
8352
8359
8360
8374
8375
8379
8380
8382
8383
8384
8385
8400
8470
8471
8722
8724
65129
65130
65284
65285
65505
65506
65509
65511
123647
123648
END
