# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToJg'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToJg'}{'missing'} = 'No_Joining_Group';

return <<'END';
620		Yeh
622	623	Alef
624		Waw
625		Alef
626		Yeh
627		Alef
628		Beh
629		Teh_Marbuta
62A	62B	Beh
62C	62E	Hah
62F	630	Dal
631	632	Reh
633	634	Seen
635	636	Sad
637	638	Tah
639	63A	Ain
63B	63C	Gaf
63D	63F	Farsi_Yeh
641		Feh
642		Qaf
643		Kaf
644		Lam
645		Meem
646		Noon
647		Heh
648		Waw
649	64A	Yeh
66E		Beh
66F		Qaf
671	673	Alef
675		Alef
676	677	Waw
678		Yeh
679	680	Beh
681	687	Hah
688	690	Dal
691	699	Reh
69A	69C	Seen
69D	69E	Sad
69F		Tah
6A0		Ain
6A1	6A6	Feh
6A7	6A8	Qaf
6A9		Gaf
6AA		Swash_Kaf
6AB		Gaf
6AC	6AE	Kaf
6AF	6B4	Gaf
6B5	6B8	Lam
6B9	6BC	Noon
6BD		Nya
6BE		Knotted_Heh
6BF		Hah
6C0		Teh_Marbuta
6C1	6C2	Heh_Goal
6C3		Teh_Marbuta_Goal
6C4	6CB	Waw
6CC		Farsi_Yeh
6CD		Yeh_With_Tail
6CE		Farsi_Yeh
6CF		Waw
6D0	6D1	Yeh
6D2	6D3	Yeh_Barree
6D5		Teh_Marbuta
6EE		Dal
6EF		Reh
6FA		Seen
6FB		Sad
6FC		Ain
6FF		Knotted_Heh
710		Alaph
712		Beth
713	714	Gamal
715	716	Dalath_Rish
717		He
718		Syriac_Waw
719		Zain
71A		Heth
71B	71C	Teth
71D		Yudh
71E		Yudh_He
71F		Kaph
720		Lamadh
721		Mim
722		Nun
723		Semkath
724		Final_Semkath
725		E
726		Pe
727		Reversed_Pe
728		Sadhe
729		Qaph
72A		Dalath_Rish
72B		Shin
72C		Taw
72D		Beth
72E		Gamal
72F		Dalath_Rish
74D		Zhain
74E		Khaph
74F		Fe
750	756	Beh
757	758	Hah
759	75A	Dal
75B		Reh
75C		Seen
75D	75F	Ain
760	761	Feh
762	764	Gaf
765	766	Meem
767	769	Noon
76A		Lam
76B	76C	Reh
76D		Seen
76E	76F	Hah
770		Seen
771		Reh
772		Hah
773	774	Alef
775	776	Farsi_Yeh
777		Yeh
778	779	Waw
77A	77B	Burushaski_Yeh_Barree
77C		Hah
77D	77E	Seen
77F		Kaf
860		Malayalam_Nga
861		Malayalam_Ja
862		Malayalam_Nya
863		Malayalam_Tta
864		Malayalam_Nna
865		Malayalam_Nnna
866		Malayalam_Bha
867		Malayalam_Ra
868		Malayalam_Lla
869		Malayalam_Llla
86A		Malayalam_Ssa
870	882	Alef
886		Thin_Yeh
889		Noon
88A		Hah
88B	88C	Tah
88D		Gaf
88E		Vertical_Tail
8A0	8A1	Beh
8A2		Hah
8A3		Tah
8A4		Feh
8A5		Qaf
8A6		Lam
8A7		Meem
8A8	8A9	Yeh
8AA		Reh
8AB		Waw
8AC		Rohingya_Yeh
8AE		Dal
8AF		Sad
8B0		Gaf
8B1		Straight_Waw
8B2		Reh
8B3		Ain
8B4		Kaf
8B5		Qaf
8B6	8B8	Beh
8B9		Reh
8BA		Yeh
8BB		African_Feh
8BC		African_Qaf
8BD		African_Noon
8BE	8C0	Beh
8C1		Hah
8C2		Gaf
8C3		Ain
8C4		African_Qaf
8C5	8C6	Hah
8C7		Lam
8C8		Gaf
10AC0		Manichaean_Aleph
10AC1	10AC2	Manichaean_Beth
10AC3	10AC4	Manichaean_Gimel
10AC5		Manichaean_Daleth
10AC7		Manichaean_Waw
10AC9	10ACA	Manichaean_Zayin
10ACD		Manichaean_Heth
10ACE		Manichaean_Teth
10ACF		Manichaean_Yodh
10AD0	10AD2	Manichaean_Kaph
10AD3		Manichaean_Lamedh
10AD4		Manichaean_Dhamedh
10AD5		Manichaean_Thamedh
10AD6		Manichaean_Mem
10AD7		Manichaean_Nun
10AD8		Manichaean_Samekh
10AD9	10ADA	Manichaean_Ayin
10ADB	10ADC	Manichaean_Pe
10ADD		Manichaean_Sadhe
10ADE	10AE0	Manichaean_Qoph
10AE1		Manichaean_Resh
10AE4		Manichaean_Taw
10AEB		Manichaean_One
10AEC		Manichaean_Five
10AED		Manichaean_Ten
10AEE		Manichaean_Twenty
10AEF		Manichaean_Hundred
10D02		Hanifi_Rohingya_Pa
10D09		Hanifi_Rohingya_Pa
10D19		Hanifi_Rohingya_Kinna_Ya
10D1C		Hanifi_Rohingya_Pa
10D1E		Hanifi_Rohingya_Kinna_Ya
10D20		Hanifi_Rohingya_Kinna_Ya
10D23		Hanifi_Rohingya_Kinna_Ya
END
